@@ -16,7 +16,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
-from typing import Generator, TYPE_CHECKING
+from typing import Iterator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_iot1click_devices.type_defs import (
     ListDeviceEventsResponseTypeDef,
@@ -30,7 +30,7 @@ __all__ = ("ListDeviceEventsPaginator", "ListDevicesPaginator")
 
 class ListDeviceEventsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDeviceEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDeviceEvents)
+    [Paginator.ListDeviceEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDeviceEvents)
     """
 
     def paginate(
@@ -39,20 +39,20 @@ class ListDeviceEventsPaginator(Boto3Paginator):
         FromTimeStamp: datetime,
         ToTimeStamp: datetime,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListDeviceEventsResponseTypeDef, None, None]:
+    ) -> Iterator[ListDeviceEventsResponseTypeDef]:
         """
-        [ListDeviceEvents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDeviceEvents.paginate)
+        [ListDeviceEvents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDeviceEvents.paginate)
         """
 
 
 class ListDevicesPaginator(Boto3Paginator):
     """
-    [Paginator.ListDevices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDevices)
+    [Paginator.ListDevices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDevices)
     """
 
     def paginate(
         self, DeviceType: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListDevicesResponseTypeDef, None, None]:
+    ) -> Iterator[ListDevicesResponseTypeDef]:
         """
-        [ListDevices.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDevices.paginate)
+        [ListDevices.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDevices.paginate)
         """
